@@ -4,6 +4,7 @@
 import configparser
 import logging
 import os
+import subprocess
 
 import click
 
@@ -19,6 +20,12 @@ def configure_grp(ctx):
     pass
 
 
+@configure_grp.command(help="Update griffon to latest release")
+@click.pass_context
+def update(ctx):
+    subprocess.run(["pip", "install", "--force", "griffon"])
+
+
 @configure_grp.command(name="setup", help="Create ~/.griffon and .griffonrc config file")
 def setup():
     """stub"""
